@@ -2,7 +2,8 @@ use strict;
 use warnings;
 
 package ELF::Extract::Sections::Scanner::Objdump;
-our $VERSION = '0.0105';
+our $VERSION = '0.02020308';
+
 
 
 # ABSTRACT: An C<objdump> based section scanner.
@@ -19,7 +20,7 @@ with ELF::Extract::Sections::Meta::Scanner {
     use MooseX::Has::Sugar 0.0300;
 
 
-    use MooseX::Types::Moose ( 'Bool', 'HashRef', 'RegexpRef', 'FileHandle', 'Undef','Str','Int');
+    use MooseX::Types::Moose (qw( Bool HashRef RegexpRef FileHandle Undef Str Int));
 
 
     use MooseX::Types::Path::Class ('File');
@@ -116,7 +117,7 @@ with ELF::Extract::Sections::Meta::Scanner {
 
 
     method _objdump returns (FileHandle|Undef){
-        if ( open my $fh, '-|', 'objdump', qw( -D -F ), $self->_file->cleanup->absolute ) {
+        if ( open my $fh, q{-|}, q{objdump}, qw( -D -F ), $self->_file->cleanup->absolute ) {
             return $fh;
         }
         $self->log->logconfess(qq{An error occured requesting section data from objdump $^ $@ });
@@ -128,7 +129,6 @@ with ELF::Extract::Sections::Meta::Scanner {
 
 
 
-
 =pod
 
 =head1 NAME
@@ -137,14 +137,14 @@ ELF::Extract::Sections::Scanner::Objdump - An C<objdump> based section scanner.
 
 =head1 VERSION
 
-version 0.0105
+version 0.02020308
 
 =head1 SYNOPSIS
 
-This module is a model implementaiton of a Naive and system relaint ELF Section detector.
+This module is a model implementation of a Naive and system reliant ELF Section detector.
 Its currently highly inefficient due to having to run the entire ELF through a disassembly
 process to determine the section positions and only I<guesses> at section lengths by
-advertisng that it cant' compute sizes.
+advertising that it can't compute sizes.
 
 TO use this module, simply initialise L<ELF::Extract::Sections> as so
 
@@ -153,16 +153,12 @@ TO use this module, simply initialise L<ELF::Extract::Sections> as so
             scanner => "Objdump",
     );
 
-
-
 =head1 IMPLEMENTS ROLES
 
 =head2 ELF::Extract::Sections::Meta::Scanner
 
 L<ELF::Extract::Sections::Meta::Scanner>
 
-
-
 =head1 DEPENDS
 
 =head2 MooseX::Has::Sugar
@@ -171,76 +167,56 @@ Lots of keywords.
 
 L<MooseX::Has::Sugar>
 
-
-
 =head2 MooseX::Types::Moose
 
 Type Constraining Keywords.
 
 L<MooseX::Types::Moose>
 
-
-
 =head2 MooseX::Types::Path::Class
 
 File Type Constraints w/ Path::Class
 
 L<MooseX::Types::Path::Class>
 
-
-
 =head1 PUBLIC METHODS
 
-
-
 =head2 -> open_file ( file => File ) : Bool I< ::Scanner >
 
 Opens the file and assigns our state to that file.
 
 L<ELF::Extract::Sections::Meta::Scanner/open_file>
 
-
-
 =head2 -> next_section () : Bool I< ::Scanner >
 
 Advances our state to the next section.
 
 L<ELF::Extract::Sections::Meta::Scanner/next_section>
 
-
-
 =head2 -> section_offset () : Int | Undef I< ::Scanner >
 
 Reports the offset of the currently open section
 
 L<ELF::Extract::Sections::Meta::Scanner/section_offset>
 
-
-
 =head2 -> section_size () : Undef I< ::Scanner >
 
 Dies, because this module can't compute section sizes.
 
 L<ELF::Extract::Sections::Meta::Scanner/section_size>
 
-
-
 =head2 -> section_name () : Str | Undef I< ::Scanner >
 
 Returns the name of the current section
 
 L<ELF::Extract::Sections::Meta::Scanner/section_name>
 
-
-
 =head2 -> can_compute_size () : Bool I< ::Scanner >
 
 Returns false
 
 L<ELF::Extract::Sections::Meta::Scanner/can_compute_size>
 
-
-
 =head1 PRIVATE ATTRIBUTES
 
 =head2 -> _header_regex : RegexpRef
@@ -253,8 +229,6 @@ Style tokens that denote objdump header names.
 
 Note: This is not XML.
 
-
-
 =head2 -> _offset_regex : RegexpRef
 
 A regular expression for identifying offset blocks in objdump's output.
@@ -263,32 +237,24 @@ They look like this:
 
   File Offset: 0xdeadbeef
 
-
-
 =head2 -> _section_header_identifier : RegexpRef
 
-A regular expression for exracting Headers and Offsets together
+A regular expression for extracting Headers and Offsets together
 
   <headername> File Offset: 0xdeadbeef
 
-
-
 =head2 -> _file : File
 
 A L<Path::Class::File> reference to a file somewhere on a system
 
 =head3 clearer -> _clear_file
 
-
-
 =head2 -> _filehandle : FileHandle
 
 A perl FileHandle that points to the output of objdump for L</_file>
 
 =head3 clearer -> _clear_file_handle
 
-
-
 =head2 -> _state : HashRef
 
 Keeps track of what we're doing, and what the next header is to return.
@@ -297,30 +263,20 @@ Keeps track of what we're doing, and what the next header is to return.
 
 =head3 clearer   -> _clear_state
 
-
-
 =head1 PRIVATE ATTRIBUTE BUILDERS
 
-
-
 =head2 -> _build__section_header_identifier : RegexpRef
 
 Assembles L</_header_regex> and L</_offset_regex>
 
 L</_section_header_identifier>
 
-
-
 =head1 PRIVATE METHODS
 
-
-
 =head2 -> _objdump : FileHandle | Undef
 
 Calls the system C<objdump> instance for the currently processing file.
 
-
-
 =head1 AUTHOR
 
   Kent Fredric <kentnl@cpan.org>
@@ -332,8 +288,7 @@ This software is copyright (c) 2009 by Kent Fredric.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
-=cut 
-
+=cut
 
 
 __END__
