@@ -2,7 +2,8 @@ use strict;
 use warnings;
 
 package ELF::Extract::Sections::Section;
-our $VERSION = '0.0105';
+our $VERSION = '0.02020308';
+
 
 
 # ABSTRACT:  An Objective reference to a section in an ELF file.
@@ -37,11 +38,11 @@ class ELF::Extract::Sections::Section {
 
 
     method to_string ( Any $other?, Bool $polarity? ) {
-        return sprintf(
-            qq{[ Section %s of size %s in %s @ %x to %x ]},
-            $self->name, $self->size, $self->source, $self->offset, $self->offset + $self->size,
-            );
-    };
+        return sprintf
+          q{[ Section %s of size %s in %s @ %x to %x ]},
+          $self->name, $self->size, $self->source, $self->offset, $self->offset + $self->size,
+          ;
+      };
 
 
     method compare ( ELF::Extract::Sections::Section :$other! , FilterField :$field! ){
@@ -60,13 +61,13 @@ class ELF::Extract::Sections::Section {
 
     method write_to( File :$file does coerce  ){
         my $fh = $self->source->openr;
-        seek( $fh, $self->offset, 0 );
+        seek $fh, $self->offset, 0;
         my $output     = $file->openw;
         my $chunksize  = 1024;
         my $bytes_left = $self->size;
         my $chunk      = ( $bytes_left < $chunksize ) ? $bytes_left : $chunksize;
-        while ( read( $fh, my $buffer, $chunk ) ) {
-            print {$output} $buffer;
+        while ( read $fh, my $buffer, $chunk  ) {
+            print {$output} $buffer or Carp::croak("Write to $file failed");
             $bytes_left -= $chunksize;
             $chunk = ( $bytes_left < $chunksize ) ? $bytes_left : $chunksize;
         }
@@ -76,9 +77,9 @@ class ELF::Extract::Sections::Section {
 
     method contents {
         my $fh = $self->source->openr;
-        seek( $fh, $self->offset, 0 );
+        seek $fh, $self->offset, 0;
         my $b;
-        read( $fh, $b, $self->size );
+        read $fh, $b, $self->size;
         return $b;
     };
 };
@@ -87,7 +88,6 @@ class ELF::Extract::Sections::Section {
 
 
 
-
 =pod
 
 =head1 NAME
@@ -96,14 +96,7 @@ ELF::Extract::Sections::Section - An Objective reference to a section in an ELF
 
 =head1 VERSION
 
-version 0.0105
-
-=head1 DESCRIPTION
-
-Generally Intended for use by L<ELF::Extract::Sections> as a meta-structure for tracking data,
-but generated objects are returned to you for you to  deal with
-
-
+version 0.02020308
 
 =head1 SYNOPSIS
 
@@ -133,56 +126,43 @@ but generated objects are returned to you for you to  deal with
   # Retuns the sections contents as a string
   print $s->contents;
 
+=head1 DESCRIPTION
 
+Generally Intended for use by L<ELF::Extract::Sections> as a meta-structure for tracking data,
+but generated objects are returned to you for you to  deal with
 
 =head1 PUBLIC ATTRIBUTES
 
-
-
 =head2 source
 
 C<Str>|C<Path::Class::File>: Either a String or a Path::Class instance pointing to the file in mention.
 
-
-
 =head2 name
 
 C<Str>: The ELF Section Name
 
-
-
 =head2 offset
 
 C<Int>: Position in bytes relative to the start of the file.
 
-
-
 =head2 size
 
 C<Int>: The ELF Section Size
 
-
-
 =head1 PUBLIC METHODS
 
-
-
 =head2 -> new ( %ATTRIBUTES )
 
 4 Parameters, all required.
 
 Returns an C<ELF::Extract::Sections::Section> object.
 
-
-
 =head2 -> to_string
 
 returns C<Str> description of the object
 
     [ Section {name} of size {size} in {file} @ {start} to {stop} ]
 
-
-
 =head2 -> compare ( other => $other, field => $field )
 
 2 Parameters, both required
@@ -197,12 +177,10 @@ C<ELF::Extract::Sections::Section>: Item to compare with
 
 C<Str['name','offset','size']>: Field to compare with.
 
-=back 
+=back
 
 returns C<Int> of comparison result, between -1 and 1
 
-
-
 =head2 -> write_to ( file => $file )
 
 B<UNIMPLEMENTED AS OF YET>
@@ -213,16 +191,12 @@ B<UNIMPLEMENTED AS OF YET>
 
 C<Str>|C<Path::Class::File>: File target to write section contents to.
 
-=back 
-
-
+=back
 
 =head2 -> contents
 
 returns C<Str> of binary data read out of file.
 
-
-
 =head1 AUTHOR
 
   Kent Fredric <kentnl@cpan.org>
@@ -234,8 +208,7 @@ This software is copyright (c) 2009 by Kent Fredric.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
-=cut 
-
+=cut
 
 
 __END__
